'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /* This forms reducer create form state for each form
                                                                                                                                                                                                                                                                  The structure of state is as below
                                                                                                                                                                                                                                                                  {
                                                                                                                                                                                                                                                                    'form-name' : {
                                                                                                                                                                                                                                                                      'field-name' : { value: 'field-value', validationResult: { result : true | false } },
                                                                                                                                                                                                                                                                      'schema': { ... },
                                                                                                                                                                                                                                                                      'valid': true | false,
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                  */

var _lodash = require('lodash');

var _formsActionTypes = require('../actions/forms-action-types');

var _formsActionTypes2 = _interopRequireDefault(_formsActionTypes);

var _formValidation = require('./form-validation');

var _util = require('../util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var changeFormField = function changeFormField(forms, payload) {
  if ((0, _util.isNullOrUndefined)(payload.form) || (0, _util.isNullOrUndefined)(payload.field)) {
    return forms;
  }

  var form = forms[payload.form];
  if ((0, _util.isNullOrUndefined)(form)) {
    return forms;
  }
  var fieldData = (0, _formValidation.validateSingleField)(payload.field, payload.value, form.schema[payload.field]);

  if ((0, _util.isNullOrUndefined)(fieldData)) {
    return forms;
  }
  var newFormData = _extends({}, forms[payload.form], _defineProperty({}, payload.field, fieldData));
  newFormData.valid = (0, _formValidation.isFormValid)(newFormData);
  var newForms = _extends({}, forms, _defineProperty({}, payload.form, newFormData));
  return newForms;
};

var addValueToArrayField = function addValueToArrayField(forms, payload) {
  if (!payload.form && !payload.field && !payload.value && !(0, _lodash.isArray)(payload.field)) {
    return forms;
  }
  var form = forms[payload.form];
  var newArray = form[payload.field] ? [].concat(_toConsumableArray(form[payload.field].value), [payload.value]) : [payload.value];
  return _extends({}, forms, _defineProperty({}, payload.form, _extends({}, forms[payload.form], _defineProperty({}, payload.field, { value: newArray, validationResult: { result: true } }))));
};

var removeValueFromArrayField = function removeValueFromArrayField(forms, payload) {
  if (!payload.form && !payload.field && !payload.value && !(0, _lodash.isArray)(payload.field)) {
    return forms;
  }
  var form = forms[payload.form];
  if ((0, _util.isNullOrUndefined)(form[payload.field]) || !(0, _lodash.isArray)(form[payload.field].value)) {
    return forms;
  }

  if (payload.value >= form[payload.field].value.length) {
    return forms;
  }

  var newArray = [].concat(_toConsumableArray(form[payload.field].value.slice(0, payload.value)), _toConsumableArray(form[payload.field].value.slice(payload.value + 1)));
  return _extends({}, forms, _defineProperty({}, payload.form, _extends({}, forms[payload.form], _defineProperty({}, payload.field, { value: newArray, validationResult: { result: true } }))));
};

var addForm = function addForm(forms, payload) {
  if ((0, _util.isNullOrUndefined)(payload.form) || (0, _util.isNullOrUndefined)(payload.schema)) {
    return forms;
  }
  var data = (0, _formValidation.validateObject)(payload.data, payload.schema);
  var formData = (0, _lodash.cloneDeep)(data);
  formData.schema = (0, _lodash.cloneDeep)(payload.schema);
  formData.valid = (0, _formValidation.isFormValid)(formData);
  return _extends({}, forms, _defineProperty({}, payload.form, formData));
};

var clearForm = function clearForm(forms, payload) {
  if ((0, _util.isNullOrUndefined)(payload.form)) {
    return forms;
  }
  var oldFormData = forms[payload.form];
  if ((0, _util.isNullOrUndefined)(oldFormData)) {
    return forms;
  }

  var data = (0, _formValidation.validateObject)({}, oldFormData.schema);
  var formData = _extends({}, data);
  formData.schema = (0, _lodash.cloneDeep)(oldFormData.schema);
  formData.valid = (0, _formValidation.isFormValid)(formData);
  return _extends({}, forms, _defineProperty({}, payload.form, formData));
};

var deleteFormFromState = function deleteFormFromState(forms, payload) {
  if ((0, _util.isNullOrUndefined)(payload) || (0, _util.isNullOrUndefined)(payload.form)) {
    return forms;
  }
  var newState = _extends({}, forms);
  if (newState[payload.form]) {
    delete newState[payload.form];
  }
  return newState;
};

exports.default = function () {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments[1];

  switch (action.type) {
    case _formsActionTypes2.default.INIT_FORM:
      return addForm(state, action.payload);
    case _formsActionTypes2.default.FORM_FIELD_CHANGE:
      return changeFormField(state, action.payload);
    case _formsActionTypes2.default.ADD_VALUE_TO_ARRAY_FIELD:
      return addValueToArrayField(state, action.payload);
    case _formsActionTypes2.default.REMOVE_VALUE_FROM_ARRAY_FIELD:
      return removeValueFromArrayField(state, action.payload);
    case _formsActionTypes2.default.CLEAR_FORM:
      return clearForm(state, action.payload);
    case _formsActionTypes2.default.DELETE_FORM:
      return deleteFormFromState(state, action.payload);
    default:
      return state;
  }
};