'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isDefined = exports.isNullOrUndefined = undefined;

var _lodash = require('lodash');

var isNullOrUndefined = exports.isNullOrUndefined = function isNullOrUndefined(value) {
  return (0, _lodash.isNull)(value) || (0, _lodash.isUndefined)(value);
};

var isDefined = exports.isDefined = function isDefined(value) {
  return !isNullOrUndefined(value);
};

exports.default = {
  getDefaultValues: function getDefaultValues(formSchema) {
    var defaultValues = {};
    (0, _lodash.forOwn)(formSchema, function (value, key) {
      if (value && value.defaultValue) {
        defaultValues[key] = value.defaultValue;
      }
    });
    return defaultValues;
  },
  numToWord: function numToWord(inputNumber) {
    var str = new String(inputNumber);
    var splt = str.split('');
    var rev = splt.reverse();
    var once = ['Zero', ' One', ' Two', ' Three', ' Four', ' Five', ' Six', ' Seven', ' Eight', ' Nine'];
    var twos = ['Ten', ' Eleven', ' Twelve', ' Thirteen', ' Fourteen', ' Fifteen', ' Sixteen', ' Seventeen', ' Eighteen', ' Nineteen'];
    var tens = ['', 'Ten', ' Twenty', ' Thirty', ' Forty', ' Fifty', ' Sixty', ' Seventy', ' Eighty', ' Ninety'];

    var numLength = rev.length;
    var word = new Array();
    var j = 0;
    var i = 0;

    for (i = 0; i < numLength; i++) {
      switch (i) {

        case 0:
          if (rev[i] == 0 || rev[i + 1] == 1) {
            word[j] = '';
          } else {
            word[j] = '' + once[rev[i]];
          }
          word[j] = word[j];
          break;

        case 1:
          aboveTens();
          break;

        case 2:
          if (rev[i] == 0) {
            word[j] = '';
          } else if (rev[i - 1] == 0 || rev[i - 2] == 0) {
            word[j] = once[rev[i]] + ' Hundred';
          } else {
            word[j] = once[rev[i]] + ' Hundred and';
          }
          break;

        case 3:
          if (rev[i] == 0 || rev[i + 1] == 1) {
            word[j] = '';
          } else {
            word[j] = once[rev[i]];
          }
          if (rev[i + 1] != 0 || rev[i] > 0) {
            word[j] = word[j] + ' Thousand';
          }
          break;

        case 4:
          aboveTens();
          break;

        case 5:
          if (rev[i] == 0 || rev[i + 1] == 1) {
            word[j] = '';
          } else {
            word[j] = once[rev[i]];
          }
          if (rev[i + 1] !== '0' || rev[i] > '0') {
            word[j] = word[j] + ' Lakh';
          }
          break;

        case 6:
          aboveTens();
          break;

        case 7:
          if (rev[i] == 0 || rev[i + 1] == 1) {
            word[j] = '';
          } else {
            word[j] = once[rev[i]];
          }
          if (rev[i + 1] !== '0' || rev[i] > '0') {
            word[j] = word[j] + ' Crore';
          }
          break;

        case 8:
          aboveTens();
          break;

        default:
          break;
      }
      j++;
    }

    function aboveTens() {
      if (rev[i] == 0) {
        word[j] = '';
      } else if (rev[i] == 1) {
        word[j] = twos[rev[i - 1]];
      } else {
        word[j] = tens[rev[i]];
      }
    }

    word.reverse();
    var finalOutput = '';
    for (i = 0; i < numLength; i++) {
      finalOutput = finalOutput + word[i];
    }
    return finalOutput;
  },
  stringToNumber: function stringToNumber(value) {
    return (0, _lodash.toNumber)(value);
  },
  fixDouble: function fixDouble(value) {
    var decimalPlaces = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

    if ((0, _lodash.isNumber)(value)) {
      var valueInString = value.toFixed(decimalPlaces);
      return (0, _lodash.toNumber)(valueInString);
    }
    return value;
  }
};